@@ -1,12 +1,12 @@
 #'
 #'
 #' Shrink the Leaves of a Dendrogram Based on a Spectra Object
-#' 
+#'
 #' This function shrinks the size of leaves of a dendrogram object.  The code
 #' was taken from the help files.  An internal function, not generally called
 #' by the user.
-#' 
-#' 
+#'
+#'
 #' @param n A node in a dendrogram object.
 #'
 #' @param spectra An object of S3 class \code{Spectra}.
@@ -25,21 +25,22 @@
 #'
 .shrinkLeaf <- function(n, spectra) { # this is called iteratively by dendrapply
 
-# A little trick to color leaves properly, derived from the archives
-# Part of the ChemoSpec package
-# Bryan Hanson, DePauw University, June 2008
+  # A little trick to color leaves properly, derived from the archives
+  # Part of the ChemoSpec package
+  # Bryan Hanson, DePauw University, June 2008
 
-	lab.size = 1.0
-	if(length(spectra$names) > 20) lab.size = 0.75
-	if(length(spectra$names) > 50) lab.size = 0.5
-	
-	if(is.leaf(n)) {
-		a <- attributes(n)
-		i <- match(a$label, spectra$names)
+  lab.size <- 1.0
+  if (length(spectra$names) > 20) lab.size <- 0.75
+  if (length(spectra$names) > 50) lab.size <- 0.5
 
-		attr(n, "nodePar") <- c(a$nodePar, list(lab.col = "black",
-			pch = NA, lab.cex = lab.size))
-		}
-		n
-	}
+  if (is.leaf(n)) {
+    a <- attributes(n)
+    i <- match(a$label, spectra$names)
 
+    attr(n, "nodePar") <- c(a$nodePar, list(
+      lab.col = "black",
+      pch = NA, lab.cex = lab.size
+    ))
+  }
+  n
+}
